@@ -1,7 +1,7 @@
 import os
 from typing import Optional, Union
 from deta import Deta, _Base
-from pydantic import BaseModel, ModelMetaclass, Field
+from pydantic import BaseModel, Field
 from pydantic.main import ModelMetaclass
 from datetime import datetime
 
